@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2024 S[&]T, The Netherlands.
+ * Copyright (C) 2015-2025 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -850,10 +850,10 @@ static int prefilter_comparison(harp_dataset *dataset, uint8_t *mask, harp_opera
     {
         if (mask[i] && dataset->metadata[i] != NULL)
         {
-            double datetime_start = harp_unit_converter_convert(operation->unit_converter,
-                                                                dataset->metadata[i]->datetime_start);
-            double datetime_stop = harp_unit_converter_convert(operation->unit_converter,
-                                                               dataset->metadata[i]->datetime_stop);
+            double datetime_start = harp_unit_converter_convert_double(operation->unit_converter,
+                                                                       dataset->metadata[i]->datetime_start);
+            double datetime_stop = harp_unit_converter_convert_double(operation->unit_converter,
+                                                                      dataset->metadata[i]->datetime_stop);
 
             switch (operation->operator_type)
             {
